function fit = IMPExtrapLogConv_sol
% Compute the empirical convergence order of the extrapolated mid-point
% rule (IMPExtrapLog) for the logistic differential equation
% y' = lambda*y*(1-y).
%
% See also IMPEXTRAPLOG.
  
  lambda = 10;
  y0 = [0.2];
  T = [0 0.2];
  h = 2.^-[4:9];
  
  err = nan(size(h));

  for j=1:length(h)
    [t,y,h(j)] = IMPExtrapLog_sol(h(j), y0, T, lambda);
    err(j) = norm( y(end) - sol(t(end),y0,lambda) );
  end
  
  figure;
  loglog(h,err,'bx:')
  grid on;
  title('\bf log--log plot of error vs. step size');
  xlabel('h');
  ylabel('err');

  fit = polyfit(log(h),log(err),1);
  fprintf('numerically determined convergence order: %f\n',fit(1));

  return
  
function y = sol(t,y0,lambda)
% Exact solution for y' = LAMBDA*y*(1-y) with starting value at time(s) T.
  
  y = 1./( 1 + (y0^-1 - 1)*exp(-lambda*t) );

  return
  
